netapp_ontap.models.bgp_peer_group_peer API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.bgp_peer_group_peer`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class BgpPeerGroupPeerSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the BgpPeerGroupPeer object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `address: str GET POST PATCH`

    Peer router address

    Example: 10.10.10.7

  `asn: Size GET POST`

    Autonomous system number of peer

  `is_next_hop: bool GET POST PATCH`

    Use peer address as next hop.

  `md5_enabled: bool GET POST PATCH`

    Enable or disable TCP MD5 signatures per RFC 2385.

    Example: true

  `md5_secret: str GET POST PATCH`

    The shared TCP MD5 secret key. This can either be given as a password or hexadecimal key.

    Example: SECRET_WORD